Class: OpenTelemetry::Instrumentation::ActionView::Instrumentation
- Inherits:
-
Base
- Object
- Base
- OpenTelemetry::Instrumentation::ActionView::Instrumentation
- Defined in:
- lib/opentelemetry/instrumentation/action_view/instrumentation.rb
Overview
The Instrumentation class contains logic to detect and install the ActionView instrumentation
Installation and configuration of this instrumentation is done within the OpenTelemetry::SDK#configure block, calling use() or use_all().
Configuration keys and options
:disallowed_notification_payload_keys
Specifies an array of keys that should be excluded from the notification payload as span attributes.
:notification_payload_transform
procdefaultnil
Specifies custom proc used to extract span attributes form the notification payload. Use this to rename keys, extract nested values, or perform any other custom logic.
:legacy_span_names
booleandefaultfalse
Specifies whether spans names should use the legacy format where the subscription was reverse ordered and white space separated. (Ex. action_view render_template)
If set to true, the span name will match the name of the notification itself. (Ex. render_template.action_view)
Constant Summary collapse
- MINIMUM_VERSION =
Gem::Version.new('7')